You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@groovy.apache.org by pa...@apache.org on 2021/04/06 06:12:41 UTC

[groovy] branch GROOVY_2_4_X updated: GROOVY-9958: default to Groovy artifactory instance not jcenter/bintray

This is an automated email from the ASF dual-hosted git repository.

paulk pushed a commit to branch GROOVY_2_4_X
in repository https://gitbox.apache.org/repos/asf/groovy.git


The following commit(s) were added to refs/heads/GROOVY_2_4_X by this push:
     new c51c9eb  GROOVY-9958: default to Groovy artifactory instance not jcenter/bintray
c51c9eb is described below

commit c51c9ebc50f867309acbe97c3c9f8fc289520737
Author: Paul King <pa...@asert.com.au>
AuthorDate: Tue Apr 6 10:40:13 2021 +1000

    GROOVY-9958: default to Groovy artifactory instance not jcenter/bintray
---
 gradle/publish.gradle | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/gradle/publish.gradle b/gradle/publish.gradle
index f74b9dd..fa97188 100644
--- a/gradle/publish.gradle
+++ b/gradle/publish.gradle
@@ -46,7 +46,7 @@ allprojects {
         apply plugin: 'com.jfrog.artifactory-upload'
 
         artifactory {
-            contextUrl = project.hasProperty('artifactoryContext') ? project.artifactoryContext : 'https://oss.jfrog.org'
+            contextUrl = project.hasProperty('artifactoryContext') ? project.artifactoryContext : 'https://groovy.jfrog.io/artifactory'
             resolve {
                 repository {
                     repoKey = 'libs-release'
@@ -55,9 +55,9 @@ allprojects {
             publish {
                 excludePatterns = "org/codehaus/groovy/groovy/*/groovy-all-*,org/codehaus/groovy/groovy/*/groovy-bom-*,org/codehaus/groovy/groovy/*/groovy-backports-*,org/codehaus/groovy/groovy/*/groovy-binary-*"
                 repository {
-                    repoKey = project.hasProperty('artifactoryRepoKey') ? project.artifactoryRepoKey : 'oss-snapshot-local'
+                    repoKey = project.hasProperty('artifactoryRepoKey') ? project.artifactoryRepoKey : 'libs-snapshot-local'
                     //The Artifactory repository key to publish to
                     //when using oss.jfrog.org the credentials are from Bintray. For local build we expect them to be found in
                     //~/.gradle/gradle.properties, otherwise to be set in the build server
                     username = rootProject.artifactoryUser
                     password = rootProject.artifactoryPassword
@@ -55,9 +55,9 @@ allprojects {
                     //The Artifactory repository key to publish to
-                    //when using oss.jfrog.org the credentials are from Bintray. For local build we expect them to be found in
+                    //when using groovy.jfrog.io the credentials are for the artifactory instance. For local build we expect them to be found in
                     //~/.gradle/gradle.properties, otherwise to be set in the build server
                     username = rootProject.artifactoryUser